@@ -29,6 +29,7 @@ local rspamd_ip = require "rspamd_ip"
 local lua_util = require "lua_util"
 local lua_selectors = require "lua_selectors"
 local lua_maps = require "lua_maps"
+local lua_mime = require "lua_mime"
 local redis_params
 local fun = require "fun"
 local N = 'multimap'
@@ -453,19 +454,19 @@ local function apply_content_filter(task, filter)
     return { task:get_raw_headers() }
   elseif filter == 'text' then
     local ret = {}
-    for _, p in ipairs(task:get_text_parts()) do
+    for _, p in ipairs(lua_mime.get_distinct_text_parts(task)) do
       table.insert(ret, p:get_content())
     end
     return ret
   elseif filter == 'rawtext' then
     local ret = {}
-    for _, p in ipairs(task:get_text_parts()) do
+    for _, p in ipairs(lua_mime.get_distinct_text_parts(task)) do
       table.insert(ret, p:get_content('raw_parsed'))
     end
     return ret
   elseif filter == 'oneline' then
     local ret = {}
-    for _, p in ipairs(task:get_text_parts()) do
+    for _, p in ipairs(lua_mime.get_distinct_text_parts(task)) do
       table.insert(ret, p:get_content_oneline())
     end
     return ret
@@ -1118,6 +1119,7 @@ local function multimap_on_load_gen(rule)
     lua_util.debugm(N, rspamd_config, "loaded map object for rule %s", rule['symbol'])
     local known_symbols = {}
     rule.map_obj:foreach(function(key, value)
+      local mult = rule.score or 1.0
       local r, symbol, score, _ = parse_multimap_value(rule, value)
 
       if r and symbol and not known_symbols[symbol] then
@@ -1127,11 +1129,11 @@ local function multimap_on_load_gen(rule)
           name = symbol,
           parent = rule.callback_id,
           type = 'virtual',
-          score = score,
+          score = score * mult,
         }
         rspamd_config:set_metric_symbol({
           group = N,
-          score = 1.0, -- In future, we will parse score from `get_value` and use it as multiplier
+          score = mult, -- In future, we will parse score from `get_value` and use it as multiplier
           description = 'Automatic symbol generated by rule: ' .. rule.symbol,
           name = symbol,
         })
